@@ -2,19 +2,20 @@
 Implements a Text based app.
 """
 
-from duino_bus.bus import IBus
+from typing import Any, Dict
+
 from duino_cli.command_line import CommandLine
 
 
 class TextApp:  # pylint: disable=too-few-public-methods
     """Traditional console based application."""
 
-    def __init__(self, history_filename: str) -> None:
+    def __init__(self, params: Dict[str, Any]) -> None:
         """Constructor."""
-        self.history_filename = history_filename
+        self.params = params
 
-    def run(self, bus: IBus) -> None:
+    def run(self) -> None:
         """Runs the application."""
-        cli = CommandLine(bus, history_filename=self.history_filename)
+        cli = CommandLine(self.params)
         cli.auto_cmdloop('')
         cli.save_history()
